{% extends "aparnik/base_site.html" %}

{% load static aparnik %}

{% block content %}

    <button type="button"><a href="{{ install_app_url }}" class="button">Install App</a></button>
    <h1>{{ title }}</h1>
    <div>
        <p>{{ description }}</p>
    </div>
    {% include 'aparnik/open_application.html' %}
{% endblock %}
