# Generated by Django 2.2 on 2021-11-29 09:37

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('orders', '0012_auto_20190615_1430'),
    ]

    operations = [
        migrations.AddField(
            model_name='order',
            name='whom',
            field=models.CharField(blank=True, db_index=True, max_length=255, null=True, verbose_name='Whom'),
        ),
    ]
