# Generated by Django 2.2 on 2019-08-10 18:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('notifications', '0007_auto_20190622_0842'),
    ]

    operations = [
        migrations.AlterField(
            model_name='notification',
            name='title',
            field=models.CharField(max_length=255, verbose_name='Title'),
        ),
    ]
