# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2019-01-20 17:24


import colorfield.fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('buttons', '0005_button_title_color'),
    ]

    operations = [
        migrations.AlterField(
            model_name='button',
            name='background_color',
            field=colorfield.fields.ColorField(default='#2672DF', max_length=18, verbose_name='\\u0631\\u0646\\u06af \\u067e\\u0633 \\u0632\\u0645\\u06cc\\u0646\\u0647'),
        ),
        migrations.AlterField(
            model_name='button',
            name='icon_color',
            field=colorfield.fields.ColorField(default='#2672DF', max_length=18, verbose_name='\\u0631\\u0646\\u06af \\u0622\\u06cc\\u06a9\\u0646'),
        ),
        migrations.AlterField(
            model_name='button',
            name='title_color',
            field=colorfield.fields.ColorField(default='#2672DF', max_length=18, verbose_name='Title color'),
        ),
    ]
