# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-12-13 16:11


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('basemodels', '0008_auto_20181211_1552'),
        ('segments', '0005_remove_basesegment_model_obj'),
    ]

    operations = [
        migrations.AddField(
            model_name='basesegment',
            name='model_obj',
            field=models.ManyToManyField(through='segments.SegmentSort', to='basemodels.BaseModel', verbose_name='\\u0686\\u0647 \\u0686\\u06cc\\u0632 \\u0631\\u0627 \\u0646\\u0645\\u0627\\u06cc\\u0634 \\u062f\\u0647\\u062f\\u061f'),
        ),
    ]
