# Generated by Django 2.2 on 2019-07-01 09:11

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('filefields', '0011_auto_20190615_1430'),
    ]

    operations = [
        migrations.AddField(
            model_name='filefield',
            name='multi_quality',
            field=models.BooleanField(default=False, verbose_name='Multi Quality'),
        ),
        migrations.AddField(
            model_name='filefield',
            name='multi_quality_processing',
            field=models.IntegerField(default=-1, verbose_name='Multi Quality Processing'),
        ),
    ]
