# Generated by Django 2.2 on 2020-04-11 12:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aboutus', '0004_auto_20200405_1628'),
    ]

    operations = [
        migrations.AlterField(
            model_name='information',
            name='address',
            field=models.CharField(blank=True, max_length=255, null=True, verbose_name='Address'),
        ),
    ]
