
#site-name img {
    width: 8%;
    margin-right: 2%;
}
#branding h1, #branding h1 a:link, #branding h1 a:visited, #header {
    color: #f59d03;
}
#branding {
    width: 50%;
    float: left;
}
#user-tools {
    float: right;
}
.dashboard #content {
    width: auto;
}
#changelist .actions select {
    color: rgb(156, 153, 153);
    /*font-size: 12px;*/
}
#changelist .actions .button, form .form-row p.datetime {
    color: #9899a3;
}
#changelist #toolbar form input[type="submit"] {
    padding: 0px 10px;
}

.defaultSkin table.mceLayout {
	width: 80% !important;
	height: 70vh !important;
}
.defaultSkin .mceIframeContainer {
	height: 100%;
}

.defaultSkin iframe {
	height: 100vh !important;
}
