# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2019-01-21 21:01


from django.db import migrations, models
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('orders', '0007_auto_20190121_1856'),
    ]

    operations = [
        migrations.AlterField(
            model_name='order',
            name='uuid',
            field=models.UUIDField(default=uuid.uuid4, editable=False, unique=True, verbose_name='Reference ID'),
        ),
    ]
