# Generated by Django 2.2 on 2021-01-03 13:03

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('azbankgateways', '0002_auto_20210102_0721'),
        ('payments', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='PaymentBank',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True, verbose_name='Created at')),
                ('update_at', models.DateTimeField(auto_now=True, verbose_name='Update at')),
                ('bank_record', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='azbankgateways.Bank', verbose_name='Bank record')),
                ('payment', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='payments.Payment', verbose_name='Payment')),
            ],
            options={
                'verbose_name': 'Payment Bank',
                'verbose_name_plural': 'Payments Bank',
                'unique_together': {('bank_record',)},
            },
        ),
    ]
