# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-12-03 15:33


from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('vouchers', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='voucher',
            name='order_item_obj',
            field=models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='voucher_order_item', to='orders.OrderItem', verbose_name='Order Item'),
        ),
    ]
