# Generated by Django 2.2 on 2020-01-07 14:03

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aboutus', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='information',
            name='short_blogs',
            field=models.ManyToManyField(blank=True, to='shortblogs.ShortBlog', verbose_name='Content Segment'),
        ),
    ]
