# Generated by Django 2.2 on 2020-04-05 16:28

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aboutus', '0003_auto_20200405_1627'),
    ]

    operations = [
        migrations.AlterField(
            model_name='information',
            name='socials',
            field=models.ManyToManyField(blank=True, to='socials.SocialNetwork', verbose_name='Socials'),
        ),
    ]
