# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-12-14 13:30


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('basemodels', '0008_auto_20181211_1552'),
    ]

    operations = [
        migrations.AddField(
            model_name='basemodel',
            name='sort',
            field=models.IntegerField(default=0, verbose_name='\\u0645\\u0631\\u062a\\u0628 \\u0633\\u0627\\u0632\\u06cc'),
        ),
    ]
