# Generated by Django 2.2 on 2020-04-05 16:27

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aboutus', '0002_auto_20200107_1403'),
    ]

    operations = [
        migrations.AlterField(
            model_name='information',
            name='phone',
            field=models.CharField(blank=True, default='', max_length=15, verbose_name='Phone Number'),
        ),
    ]
