# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-11-03 02:49


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('reviews', '0003_reviewsummary'),
    ]

    operations = [
        migrations.AddField(
            model_name='reviewsummary',
            name='percentage',
            field=models.FloatField(default=10, verbose_name='Percentage'),
            preserve_default=False,
        ),
    ]
