{% load i18n static aparnik %}
<!DOCTYPE html>
{% get_current_language as LANGUAGE_CODE %}{% get_current_language_bidi as LANGUAGE_BIDI %}
<html lang="{{ LANGUAGE_CODE|default:"en-us" }}" {% if LANGUAGE_BIDI %}dir="rtl"{% endif %}>
<head>
    <title>{% site_name_persian %} | {% block title %}{{ title }}{% endblock %}</title>
    <link rel="shortcut icon" href="{{ logo }}"/>
    {% block extrastyle %}{% endblock %}

    {% if LANGUAGE_BIDI %}

    {% endif %}

    {% block extrahead %}{% endblock %}
    {% block extrameta %}{% endblock %}
    {% block blockbots %}
        <meta name="robots" content="index, follow">{% endblock %}
    <meta charset="utf-8">
    {#        <link rel="canonical" href="{{ request.get_full_path }}" />#}
    <meta name="author" content="{{ site_name_english }}">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta property="og:locale" content="{{ LANGUAGE_CODE|default:"en-us" }}"/>
    <meta property="og:type" content="website"/>
    <meta name="description" content="{% block description %}{% endblock %}"/>
    {#        <meta name="google-site-verification" content="{% block google_site_verification %}{% endblock %}" />#}
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta property="og:url" content="{{ request.META.HTTP_HOST }}"/>
    <meta property="og:title" content="{{ site_name_persian }} | {{ title }}"/>
    <meta property="og:site_name" content="{{ site_name_persian }}"/>
    <meta name="twitter:title" content="{{ site_name_persian }} | {{ title }}"/>

    {# # TODO: add summary #}
    <meta name="twitter:card" content="summary"/>

    <link href="http://maxcdn.bootstrapcdn.com/bootstrap/4.0.0/css/bootstrap.min.css" rel="stylesheet"
          id="bootstrap-css">
    <link rel="stylesheet" href='{% static "aparnik/css/bootstrap.min.css" %}'>
    <link rel="stylesheet" href='{% static "aparnik/css/bootstrap-responsive.min.css" %}'>

    <link rel="stylesheet" href="http://cdnjs.cloudflare.com/ajax/libs/bootstrap-select/1.5.4/bootstrap-select.min.css">
    <link rel="stylesheet" href="https://use.fontawesome.com/releases/v5.6.3/css/all.css"
          integrity="sha384-UHRtZLI+pbxtHCWp1t77Bi1L4ZtiqrqD80Kn4Z8NTSRyMA2Fd33n5dQ8lWUE00s/" crossorigin="anonymous">

    <link rel="stylesheet" href="{% static "aparnik/owlcarousel/owl.carousel.min.css" %}">
    <link rel="stylesheet" href="{% static "aparnik/owlcarousel/owl.theme.default.min.css" %}">
    <link rel="stylesheet" href="{% static "aparnik/owlcarousel/animate.css" %}">

    <link rel="stylesheet" href="https://cdn.aparnik.com/static/fonts/IRANSansWebFonts/css/fontiran.css">
    <link rel="stylesheet" href='{% static "aparnik/css/style.css" %}'>

    <script src='{% static "aparnik/js/jquery-3.3.1.js" %}'></script>

    <script src='{% static "aparnik/js/bootstrap.min.js" %}'></script>
    <!-- HTML5 Shim and Respond.js IE8 support of HTML5 elements and media queries -->
    <!-- WARNING: Respond.js doesn"t work if you view the page via file:// -->
    <!--[if lt IE 9]>
		<script src="https://oss.maxcdn.com/libs/html5shiv/3.7.0/html5shiv.js"></script>
		<script src="https://oss.maxcdn.com/libs/respond.js/1.4.2/respond.min.js"></script>
		<![endif]-->


    <script src="http://code.jquery.com/jquery-1.11.1.min.js"></script>
    <script src="http://maxcdn.bootstrapcdn.com/bootstrap/4.0.0/js/bootstrap.min.js"></script>
    <!------ Include the above in your HEAD tag ---------->
    <link href="{% static "aparnik/css/style.css" %}" rel="stylesheet">
    <!-- cdnjs : use a specific version of Video.js (change the version numbers as necessary) -->
    <link href="https://cdnjs.cloudflare.com/ajax/libs/video.js/6.7.3/video-js.min.css" rel="stylesheet">
    <script src="https://cdnjs.cloudflare.com/ajax/libs/video.js/6.7.3/video.min.js"></script>
    <script src="{% static "aparnik/owlcarousel/owl.carousel.min.js" %}"></script>
    <link rel="stylesheet" href='{% static "aparnik/video/video-js.min.css" %}'>
    <link href="{% static "aparnik/video/videojs-resolution-switcher.css" %}" rel="stylesheet">
    <script src="{% static "aparnik/video/video.js" %}"></script>
    <script src="{% static "aparnik/video/videojs-resolution-switcher.js" %}"></script>

</head>
<body>


    {% block content %} {% endblock %}


</body>
</html>