# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-12-10 10:03


from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('basemodels', '0004_auto_20181103_2233'),
    ]

    operations = [
        migrations.AddField(
            model_name='basemodel',
            name='is_show_only_for_super_user',
            field=models.BooleanField(default=False, verbose_name='Show only for super user'),
        ),
    ]
