# Generated by Django 2.2 on 2019-07-14 16:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('courses', '0020_auto_20190615_1430'),
    ]

    operations = [
        migrations.AlterField(
            model_name='coursesummary',
            name='type',
            field=models.CharField(choices=[('M', 'فیلم'), ('V', 'صدا'), ('P', 'پی دی اف'), ('I', 'عکس'), ('L', 'لینک')], max_length=1, verbose_name='نوع'),
        ),
    ]
