# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2018-11-03 00:01


from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('basemodels', '0003_basemodel_update_needed'),
        ('files', '0004_file_cover'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Progresses',
            fields=[
                ('basemodel_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='basemodels.BaseModel')),
                ('is_published', models.BooleanField(default=True, verbose_name='Published')),
                ('status', models.CharField(choices=[('SN', 'Not started'), ('SS', 'Started'), ('SM', 'Manual complete'), ('SA', 'Auto complete')], default='SN', max_length=2, verbose_name='Status')),
                ('file_obj', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='files.File', verbose_name='File')),
                ('user_obj', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL, verbose_name='User')),
            ],
            options={
                'verbose_name': 'Progress',
                'verbose_name_plural': 'Progresses',
            },
            bases=('basemodels.basemodel',),
        ),
    ]
