# Generated by Django 2.2 on 2020-06-02 09:48

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('filefields', '0014_auto_20200210_1451'),
    ]

    operations = [
        migrations.AlterField(
            model_name='filefield',
            name='password',
            field=models.CharField(blank=True, default='', max_length=64, null=True, verbose_name='گذرواژه'),
        ),
    ]
