# Generated by Django 2.2 on 2021-12-23 20:12

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('products', '0018_auto_20190423_1058'),
        ('coupons', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='ProductCoupon',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('coupon_obj', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='coupons.Coupon', verbose_name='Coupon')),
                ('product_obj', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='products.Product', verbose_name='Product')),
            ],
            options={
                'verbose_name': 'Product Coupon',
                'verbose_name_plural': 'Product Coupon relations',
            },
        ),
        migrations.AddField(
            model_name='coupon',
            name='products',
            field=models.ManyToManyField(blank=True, through='coupons.ProductCoupon', to='products.Product', verbose_name='Products'),
        ),
    ]
