# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2019-04-23 10:58


import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('products', '0017_auto_20190319_1744'),
    ]

    operations = [
        migrations.AlterField(
            model_name='product',
            name='aparnik_bon_return_value',
            field=models.IntegerField(default=-1, help_text='If the number is set to -1, then the value in the settings will apply', validators=[django.core.validators.MinValueValidator(-1), django.core.validators.MaxValueValidator(100)], verbose_name='Bon Return'),
        ),
        migrations.AlterField(
            model_name='product',
            name='maximum_use_aparnik_bon_value',
            field=models.IntegerField(default=-1, help_text='If the number is set to -1, then the value in the settings will apply, If the number is set to -2, then no limitation execution.', validators=[django.core.validators.MinValueValidator(-2), django.core.validators.MaxValueValidator(100)], verbose_name='Maximum use aparnik bon'),
        ),
    ]
