# Generated by Django 2.2 on 2021-09-15 11:43

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('categories', '0003_remove_category_pages'),
    ]

    operations = [
        migrations.AddField(
            model_name='category',
            name='is_show',
            field=models.BooleanField(default=True, verbose_name='Is Show'),
        ),
    ]
